@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2011-2013 Ganael LAPLANCHE <ganael.laplanche@martymac.org>
+ * Copyright (c) 2011-2015 Ganael LAPLANCHE <ganael.laplanche@martymac.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -61,7 +61,7 @@ static void
 version(void)
 {
     fprintf(stderr, "fpart v" FPART_VERSION "\n"
-        "Copyright (c) 2011-2013 Ganael LAPLANCHE <ganael.laplanche@martymac.org>\n"
+        "Copyright (c) 2011-2015 Ganael LAPLANCHE <ganael.laplanche@martymac.org>\n"
         "WWW: http://contribs.martymac.org\n");
     fprintf(stderr, "Build options: debug=");
 #if defined(DEBUG)
@@ -653,16 +653,17 @@ int main(int argc, char **argv)
     if((totalfiles <= 0) || (options.live_mode == OPT_LIVEMODE)) {
         uninit_file_entries(head, &options);
         /* display status */
-        fprintf(stderr, "%lld file(s) found.\n", totalfiles);
+        if(options.verbose >= OPT_VERBOSE)
+            fprintf(stderr, "%lld file(s) found.\n", totalfiles);
         uninit_options(&options);
         exit(EXIT_SUCCESS);
     }
 
     /* display status */
-    fprintf(stderr, "%lld file(s) found.\n", totalfiles);
-
-    if(options.verbose >= OPT_VERBOSE)
+    if(options.verbose >= OPT_VERBOSE) {
+        fprintf(stderr, "%lld file(s) found.\n", totalfiles);
         fprintf(stderr, "Sorting entries...\n");
+    }
 
 /************************************************
   Sort entries with a fixed number of partitions
